"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createValidationMiddleware = void 0;
const prisma_nested_middleware_1 = require("prisma-nested-middleware");
const defaultCustomizeError = (error, params) => {
    error.name = "ValidationError";
    error.message = `${params.model}.${params.action}: ${error.message}`;
    return error;
};
const createValidationMiddleware = (validators, options = {}) => {
    const { customizeError = defaultCustomizeError } = options;
    return (0, prisma_nested_middleware_1.createNestedMiddleware)((params, next) => {
        if (!params.model)
            return next(params);
        const validator = validators[params.model];
        if (!validator)
            return next(params);
        try {
            switch (params.action) {
                case "upsert": {
                    validator(params.args.create);
                    validator(params.args.update);
                    break;
                }
                case "create": {
                    if (params.scope) {
                        validator(params.args);
                        break;
                    }
                    validator(params.args.data);
                    break;
                }
                case "update": {
                    if (params.scope && !params.scope.relations.to.isList) {
                        validator(params.args);
                        break;
                    }
                    validator(params.args.data);
                    break;
                }
                case "updateMany": {
                    validator(params.args.data);
                    break;
                }
                case "createMany": {
                    params.args.data.forEach((data) => {
                        validator(data);
                    });
                    break;
                }
                case "connectOrCreate": {
                    validator(params.args.create);
                    break;
                }
                default:
                    break;
            }
        }
        catch (e) {
            throw customizeError(e, params);
        }
        return next(params);
    });
};
exports.createValidationMiddleware = createValidationMiddleware;
